import seaborn as sns
import matplotlib


# general config
log_location = 'conflictlogs'
baseline_log_location = 'baselinelogs'
dataframe_name = 'CRON_sensitivity'

experiment_cases = {
    'concepts' : {
        'baseline'  : 'Baseline',
        'conflict'  : 'Conflict',
    },
    'densities' : [
        '300',
    ],
    'clusters':[
        '1000',
        '4000',
        '8000',
        '12000',
    ],
    'seeds': [
        '748180',
        '825078',
        '102890',
        '824289',
        '466213'
    ],
    'graphweights': [
        # # all clusters get an extra weight
        '1.5-1.5-1.5-1.5',
        '2-2-2-2',
        '2.5-2.5-2.5-2.5',
        '3-3-3-3',
        
        # # 25 percent to 100 percent get extra weight
        '1-1.5-1.5-1.5',
        '1-2-2-2',
        '1-2.5-2.5-2.5',
        '1-3-3-3',

        # # 50 percent to 100 percent get extra weight
        '1-1-1.5-1.5',
        '1-1-2-2',
        '1-1-2.5-2.5',
        '1-1-3-3',

        # # 75 percent to 100 percent get extra weight
        '1-1-1-1.5',
        '1-1-1-2',
        '1-1-1-2.5',
        '1-1-1-3'
    ],
    'replanlimits': [
        '0',
    ],
    'replanratios': [
        '1',
    ],
    'CR': [
       'ON',
    ],
    'logs': [
        'CONFLOG',
        'REGLOG',
        'LOSLOG',
    ]
}

# safety metric dictionary
safety_dict = {
    'CONFLOG'   : {
        'metrics': {
            'Total conflicts': {
                'yrange': {
                    'CRON': [0, 40000],
                    'CROFF': [0, 40000]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Conflicts per flight': {
                'yrange': {
                    'CRON': [0, 9],
                    'CROFF': [0, 8]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Conflicts per distance': {
                'yrange': {
                    'CRON': [0, 0.0015],
                    'CROFF': [0, 0.0015]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Conflicts per flight percentage': {
                'yrange': {
                    'CRON': [70, 120],
                    'CROFF': [80, 120]
                },
                'units': '[%]',
                'legend_loc': 'upper right'
            },
            'Conflicts per distance percentage': {
                'yrange': {
                    'CRON': [70, 120],
                    'CROFF': [80, 120]
                },
                'units': '[%]',
                'legend_loc': 'upper right'
            },
        },
        'columns': [
            'time',
            'ACID1',
            'ACID2',
            'LAT1',
            'LON1',
            'ALT1',
            'LAT2',
            'LON2',
            'ALT2',
        ]
    },
    'CDRCONFLOG': {
        'metrics': [
            'Total conflicts',
            'Conflicts per flight',
        ],
        'columns': [
            'time',
            'uniqueconfid',
            'ACID1',
            'ACID2',
            'LAT1',
            'LON1',
            'ALT1',
            'LAT2',
            'LON2',
            'ALT2',
        ]
    },
    'LOSLOG'    : {
        'metrics': {
            'Total intrusions': {
                'yrange': {
                    'CRON': [0, 6000],
                    'CROFF': [0, 17000]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Intrusions per flight': {
                'yrange': {
                    'CRON': [0, 1.1],
                    'CROFF': [0, 3]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Intrusions per distance': {
                'yrange': {
                    'CRON': [0, 0.0006],
                    'CROFF': [0, 0.0006]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Intrusions per flight percentage': {
                'yrange': {
                    'CRON': [60, 120],
                    'CROFF': [80, 130]
                    
                    # 1-3-5   and 1-2-3             
                    # 'CROFF': [90, 170]
                },
                'units': '[%]',
                'legend_loc': 'upper right'
            },
            'Intrusions per distance percentage': {
                'yrange': {
                    'CRON': [60, 120],
                    'CROFF': [80, 130]
                },
                'units': '[%]',
                'legend_loc': 'upper right'
            },
        },
        'columns': [
            'exit_time',
            'start_time',
            'mindist_time',
            'ACID1',
            'ACID2',
            'LAT1',
            'LON1',
            'ALT1',
            'LAT2',
            'LON2',
            'ALT2',
            'DIST',
        ]
    }
}

efficency_dict = {
    'FLSTLOG'   : {
        'metrics': {
            'Number of flights': {
                'yrange': {
                    'CRON': [0, 7000],
                    'CROFF': [0, 7000]
                },
                'units': '[-]',
                'legend_loc': 'lower right'
            },
            'Flight time': {
                'yrange': {
                    'CRON': [0, 3e6],
                    'CROFF': [0, 3e6]
                },
                'units': '[s]',
                'legend_loc': 'lower right'
            },
            'Distance 2D': {
                'yrange': {
                    'CRON': [0, 3e7],
                    'CROFF': [0, 3e7]
                },
                'units': '[m]',
                'legend_loc': 'lower right'
            },     
            'Flight time per flight': {
                'yrange': {
                    'CRON': [0, 800],
                    'CROFF': [0, 800]
                },
                'units': '[s]',
                'legend_loc': 'lower right'
            },
            'Distance 2D per flight': {
                'yrange': {
                    'CRON': [4500, 6000],
                    'CROFF': [4500, 6000]
                },
                'units': '[m]',
                'legend_loc': 'lower right'
            },
            'Flight time percentage': {
                'yrange': {
                    'CRON': [95, 105],
                    'CROFF': [95, 105]
                },
                'units': '[%]',
                'legend_loc': 'lower right'
            },
            'Distance 2D percentage': {
                'yrange': {
                    'CRON': [98, 110],
                    'CROFF': [98, 110]
                    
                    # 1-2-3 and 1-3-5
                    # 'CROFF': [90, 135]

                },
                'units': '[%]',
                'legend_loc': 'upper right'
            },                               
        },
        'columns': [
            'deletion_time',
            'ACID',
            'spawn_time',
            'flight_time', 
            'distance_2D', 
            'distance_3D',
            'distance_ALT', 
            'LAT', 
            'LON', 
            'ALT', 
            'TAS', 
            'vertical_speed', 
            'heading', 
            'aSAS_active', 
            'autopilot_ALT', 
            'autopilot_SPD', 
            'autopilot_HDG', 
            'autopilot_VS', 
        ]
    },
}

# floe metric dictionary
flow_dict = {
    'FLOWLOG'   : {
        'metrics': {
            'Number of attempted replans': {
                'yrange': {
                    'CRON': [0, 70000],
                    'CROFF': [0, 70000]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Number of succesful replans': {
                'yrange': {
                    'CRON': [0, 12],
                    'CROFF': [0, 8]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Percent out of attempted replans': {
                'yrange': {
                    'CRON': [0, 70000],
                    'CROFF': [0, 70000]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Percent out of total aircraft': {
                'yrange': {
                    'CRON': [0, 12],
                    'CROFF': [0, 8]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
            'Average replan per aircraft': {
                'yrange': {
                    'CRON': [0, 12],
                    'CROFF': [0, 8]
                },
                'units': '[-]',
                'legend_loc': 'upper left'
            },
        },
        'columns': [
            'time',
            'N_air',
            'N_attempted_replans',
            'N_succesful_replans',
            'percent_succesful_attempted',
            'percent_succesful_nair',
            'close_turn_replans',
            'longer_replans',
            'shorter_replans',
            'shortestpath_replans',
        ]
    },
}


# floe metric dictionary
cluster_dict = {
    'CLUSTERLOG'   : {
        'metrics': {
            'Percent of medium density clusters': {
                'yrange': {
                    'CRON': [0, 70000],
                    'CROFF': [0, 70000]
                },
                'units': '[%]',
                'legend_loc': 'upper left'
            },
            'Percent of high density clusters': {
                'yrange': {
                    'CRON': [0, 12],
                    'CROFF': [0, 8]
                },
                'units': '[%]',
                'legend_loc': 'upper left'
            },
            'Percent of medium density airspace': {
                'yrange': {
                    'CRON': [0, 40],
                    'CROFF': [0, 40]
                },
                'units': '[%]',
                'legend_loc': 'upper left'
            },
            'Percent of high density airspace': {
                'yrange': {
                    'CRON': [0, 40],
                    'CROFF': [0, 40]
                },
                'units': '[%]',
                'legend_loc': 'upper left'
            },
            'Percent of clustered airspace': {
                'yrange': {
                    'CRON': [0, 60],
                    'CROFF': [0, 60]
                },
                'units': '[%]',
                'legend_loc': 'upper left'
            },
            'Hausdorff distance for medium density airspace': {
                'yrange': {
                    'CRON': [0, 40],
                    'CROFF': [0, 40]
                },
                'units': '[m]',
                'legend_loc': 'upper left'
            },
            'Hausdorff distance for high density airspace': {
                'yrange': {
                    'CRON': [0, 40],
                    'CROFF': [0, 40]
                },
                'units': '[m]',
                'legend_loc': 'upper left'
            },
            'Hausdorff distance for total airspace': {
                'yrange': {
                    'CRON': [0, 100],
                    'CROFF': [0, 100]
                },
                'units': '[m]',
                'legend_loc': 'upper left'
            },

            'Cluster overlap percentage for medium density airspace': {
                'yrange': {
                    'CRON': [0, 40],
                    'CROFF': [0, 40]
                },
                'units': '[%]',
                'legend_loc': 'upper left',
                'ylabel': 'Cluser temporal stability medium'

            },
            'Cluster overlap percentage for high density airspace': {
                'yrange': {
                    'CRON': [0, 40],
                    'CROFF': [0, 40]
                },
                'units': '[%]',
                'legend_loc': 'upper left', 
                'ylabel': 'Cluser temporal stability high'
            },
            'Cluster overlap percentage for total airspace': {
                'yrange': {
                    'CRON': [20, 100],
                    'CROFF': [20, 100]
                },
                'units': '[%]',
                'legend_loc': 'upper right',
                'ylabel': 'Cluser temporal stability'

            },

        },
        'columns': [
            'time',
            'observation_count',
            'geometry',
            'summed_edge_length',
            'linear_density',
            'density_category',
        ]
    },
}

# floe metric dictionary
replan_dict = {
    'REPLANLOG'   : {
        'metrics': {
            'True replans per flight': {
                'yrange': {
                    'CRON': [0, 70000],
                    'CROFF': [0, 70000]
                },
                'units': '[-]',
                'legend_loc': 'upper right',
                'ylabel': 'Replans per flight'

            },
            # 'Percent of high density clusters': {
            #     'yrange': {
            #         'CRON': [0, 12],
            #         'CROFF': [0, 8]
            #     },
            #     'units': '[%]',
            #     'legend_loc': 'upper left'
            # },
        },
        # 'columns': [
        #     'time',
        #     'observation_count',
        #     'geometry',
        #     'summed_edge_length',
        #     'linear_density',
        #     'density_category',
        # ]
    },
}


# set matplotlib and seaborn default
matplotlib.use('Agg')
concepts_colours=sns.color_palette("colorblind", len(experiment_cases['concepts'].keys()))
cluster_colours=sns.color_palette("colorblind", len(experiment_cases['clusters']))
