import pandas as pd
import matplotlib.pyplot as plt
import seaborn as sns
import pandas as pd
from itertools import product

import config as cfg

# read in df
df = pd.read_csv('dataframes/CRON_sensitivity.csv')
df.loc[df["concept"] == "live", "concept"] = 'positional'

# here add the percentile and graph multiplier to the dataframe

# Define the logic for classification
def classify_weights(weight_str):
    # Split the string to get individual weights
    weights = list(map(float, weight_str.split('-')))
    last_weight = weights[-1]

    # Determine the percentile and additional weight
    if weight_str in ['1.5-1.5-1.5-1.5', '2-2-2-2', '2.5-2.5-2.5-2.5', '3-3-3-3']:
        percentile = 0
        additional_weight = last_weight
    elif weight_str in ['1-1.5-1.5-1.5', '1-2-2-2', '1-2.5-2.5-2.5', '1-3-3-3']:
        percentile = 25
        additional_weight = last_weight
    elif weight_str in ['1-1-1.5-1.5', '1-1-2-2', '1-1-2.5-2.5', '1-1-3-3']:
        percentile = 50
        additional_weight = last_weight
    elif weight_str in ['1-1-1-1.5', '1-1-1-2', '1-1-1-2.5', '1-1-1-3']:
        percentile = 75
        additional_weight = last_weight
    else:
        percentile = None
        additional_weight = None

    return percentile, additional_weight

# Apply the classification logic to create new columns
df['percentile'], df['additional_weight'] = zip(*df['graphweights'].apply(classify_weights))



# PART 1: compare different  cluster distances intrusions per flight percentage

metrics = ['Intrusions per flight percentage', 'Distance 2D percentage']

for metric in metrics:
    
    filtered_df = df[df['concept'] != 'baseline']

    sns.scatterplot(
        y=metric,
        x='cluster',
        data=filtered_df,
        hue='additional_weight',
    )


    # Add a label beneath the line
    plt.annotate('Baseline', xy=(0.5, 400), xytext=(0.5, 400 - 8),
                arrowprops=dict(facecolor='black', arrowstyle='->'), ha='center', fontsize=12)
    plt.axhline(y=100, color='k', linestyle='--') 

    # set the x,y labels
    plt.ylabel(f'{metric} [%]')
    plt.xlabel(f'Cluster distance [-]')

    # set the y limits
    # yrange = cfg.safety_dict[logtype]['metrics'][metric]['yrange'][f'CR{crCase}']
    # plt.ylim(yrange)

    # Get unique x-values from the data
    unique_x_values = filtered_df['cluster'].unique()

    # Set x-ticks to the unique values
    plt.xticks(unique_x_values)

    # place the legend
    plt.legend(loc='center left', bbox_to_anchor=(1, 0.5))

    # save figure
    plt.savefig(f'images/{metric}_clusterdistance.png',bbox_inches='tight', format='png')
    plt.clf()


# Part 2 look at percentile

filtered_df = df[(df['cluster'] == 4000)]
# filtered_df = filtered_df[(filtered_df['additional_weight'] != 3.0)]


metrics = ['Intrusions per flight percentage', 'Distance 2D percentage']

for metric in metrics:
    
    filtered_df_2 = filtered_df[filtered_df['concept'] != 'baseline']

    sns.scatterplot(
        y=metric,
        x='percentile',
        data=filtered_df_2,
        hue='additional_weight',
    )


    # Add a label beneath the line
    plt.annotate('Baseline', xy=(0.5, 400), xytext=(0.5, 400 - 8),
                arrowprops=dict(facecolor='black', arrowstyle='->'), ha='center', fontsize=12)
    plt.axhline(y=100, color='k', linestyle='--') 

    # set the x,y labels
    plt.ylabel(f'{metric} [%]')
    plt.xlabel(f'Percentile of low density airspace [%]')

    # set the y limits
    # yrange = cfg.safety_dict[logtype]['metrics'][metric]['yrange'][f'CR{crCase}']
    # plt.ylim(yrange)

    # Get unique x-values from the data
    unique_x_values = filtered_df_2['percentile'].unique()

    # Set x-ticks to the unique values
    plt.xticks(unique_x_values)

    # place the legend
    plt.legend(loc='center left', bbox_to_anchor=(1, 0.5))

    # save figure
    plt.savefig(f'images/{metric}_percentile.png',bbox_inches='tight', format='png')
    plt.clf()


# PART 3

filtered_df = filtered_df[(filtered_df['percentile'] == 25)]

metrics = ['Intrusions per flight percentage', 'Distance 2D percentage']

for metric in metrics:
    
    filtered_df_2 = filtered_df[filtered_df['concept'] != 'baseline']

    sns.boxplot(
        y=metric,
        x='additional_weight',
        data=filtered_df_2,
        hue='cluster',
    )


    # Add a label beneath the line
    plt.annotate('Baseline', xy=(0.5, 400), xytext=(0.5, 400 - 8),
                arrowprops=dict(facecolor='black', arrowstyle='->'), ha='center', fontsize=12)
    plt.axhline(y=100, color='k', linestyle='--') 

    # set the x,y labels
    plt.ylabel(f'{metric} [%]')
    plt.xlabel(f'Additional cost multiplier [-]')


    # Get unique x-values from the data
    # unique_x_values = filtered_df_2['additional_weight'].unique()
    # print(unique_x_values)
    # Set x-ticks to the unique values
    # plt.xticks(unique_x_values)

    plt.legend([],[], frameon=False)

    # set the y limits
    # yrange = cfg.safety_dict[logtype]['metrics'][metric]['yrange'][f'CR{crCase}']
    # plt.ylim(yrange)

    # place the legend
    # plt.legend(loc='center left', bbox_to_anchor=(1, 0.5))

    # save figure
    plt.savefig(f'images/{metric}_final.png',bbox_inches='tight', format='png')
    plt.clf()
